{% extends 'admin/parler/change_form.html' %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" href="/static/admin/css/modal.css">
{% endblock %}

{% block extrahead %}
    {{ block.super }}
    <script src="/static/admin/js/preview.js"></script>
{% endblock %}

{% block submit_buttons_bottom %}
    <div class="submit-row">
        <div class="preview-box">
            <input type="button" value="Preview" name="_preview" onclick="showPreviewModal()" />
        </div>
    </div>
    {{ block.super }}
{% endblock %}
