# Generated by Django 2.2.8 on 2020-01-03 21:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("django_ilmoitin", "0002_add_admin_notifications")]

    operations = [
        migrations.RemoveField(model_name="notificationtemplate", name="from_email")
    ]
